@@ -15,6 +15,7 @@
 
 require 'milter/manager/clamav-milter-config-parser'
 require 'milter/manager/milter-greylist-config-parser'
+require 'milter/manager/opendkim-config-parser'
 
 module Milter::Manager
   module Detector
@@ -28,9 +29,9 @@ module Milter::Manager
     end
 
     def apply(loader)
-      return if @name.nil?
+      return unless need_apply?
       spec = guess_spec
-      loader.define_milter(@script_name) do |milter|
+      loader.define_milter(milter_name) do |milter|
         milter.enabled = enabled?
         milter.description = description
         milter.command = command
@@ -62,12 +63,17 @@ module Milter::Manager
       clamav_milter_config_parser.example?
     end
 
+    def detect_opendkim_connection_spec
+      opendkim_config_parser.socket
+    end
+
     private
     def init_variables
       @name = nil
       @variables = {}
       @clamav_milter_config_parser = nil
       @milter_greylist_config_parser = nil
+      @opendkim_config_parser = nil
     end
 
     def set_variable(name, unnormalized_value)
@@ -153,6 +159,14 @@ module Milter::Manager
       /\A\$/ =~ string
     end
 
+    def milter_name
+      @script_name
+    end
+
+    def need_apply?
+      not @name.nil?
+    end
+
     def apply_before_block(milter)
       if respond_to?(:milter_greylist?) and milter_greylist?
         milter_greylist_config_parser.apply(milter)
@@ -179,5 +193,13 @@ module Milter::Manager
       end
       @milter_greylist_config_parser
     end
+
+    def opendkim_config_parser
+      if @opendkim_config_parser.nil?
+        @opendkim_config_parser = Milter::Manager::OpenDKIMConfigParser.new
+        @opendkim_config_parser.parse(opendkim_conf)
+      end
+      @opendkim_config_parser
+    end
   end
 end
