@@ -1,6 +1,6 @@
 /* -*- c-file-style: "ruby" -*- */
 /*
- *  Copyright (C) 2008  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2008-2009  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -37,6 +37,24 @@ client_shutdown (VALUE self)
     return Qnil;
 }
 
+static VALUE
+client_get_connection_spec (VALUE self)
+{
+    return CSTR2RVAL(milter_client_get_connection_spec(SELF(self)));
+}
+
+static VALUE
+client_set_connection_spec (VALUE self, VALUE spec)
+{
+    GError *error = NULL;
+
+    if (!milter_client_set_connection_spec(SELF(self),
+                                           StringValueCStr(spec), &error))
+        RAISE_GERROR(error);
+
+    return Qnil;
+}
+
 void
 Init_milter_client (void)
 {
@@ -45,9 +63,18 @@ Init_milter_client (void)
     rb_define_const(rb_cMilterClient,
 		    "DEFAULT_SUSPEND_TIME_ON_UNACCEPTABLE",
 		    UINT2NUM(MILTER_CLIENT_DEFAULT_SUSPEND_TIME_ON_UNACCEPTABLE));
+    rb_define_const(rb_cMilterClient,
+		    "DEFAULT_MAX_CONNECTIONS",
+		    UINT2NUM(MILTER_CLIENT_DEFAULT_MAX_CONNECTIONS));
 
     rb_define_method(rb_cMilterClient, "main", client_main, 0);
     rb_define_method(rb_cMilterClient, "shutdown", client_shutdown, 0);
+    rb_define_method(rb_cMilterClient, "connection_spec",
+                     client_get_connection_spec, 0);
+    rb_define_method(rb_cMilterClient, "set_connection_spec",
+                     client_set_connection_spec, 1);
 
+    G_DEF_SETTERS(rb_cMilterClient);
+    
     Init_milter_client_context();
 }
