@@ -60,21 +60,19 @@ class TestDebianInitDetector < Test::Unit::TestCase
                    "DESC" => "flexible milter management daemon",
                    "NAME" => "milter-manager",
                    "DAEMON" => "/usr/sbin/milter-manager",
-                   "USER" => "milter-manager",
-                   "GROUP" => "mail",
-                   "SOCKET_GROUP" => "mail",
+                   "USER" => "",
+                   "GROUP" => "",
+                   "SOCKET_GROUP" => "",
                    "PIDFILE" => "/var/run/milter-manager/milter-manager.pid",
-                   "CONNECTION_SPEC" => "unix:/var/run/milter-manager/milter-manager.sock",
+                   "CONNECTION_SPEC" => "",
                    "SCRIPTNAME" => "/etc/init.d/milter-manager",
                    "DAEMON_ARGS" => ["--daemon",
                                      "--pid-file",
                                      "/var/run/milter-manager/milter-manager.pid",
-                                     "--connection-spec",
-                                     "unix:/var/run/milter-manager/milter-manager.sock",
-                                     "--user-name",
-                                     "milter-manager",
-                                     "--group-name", "mail",
-                                     "--socket-group-name", "mail",
+                                     "--connection-spec", "",
+                                     "--user-name", "",
+                                     "--group-name", "",
+                                     "--socket-group-name", "",
                                     ].join(" ") + " ",
                    "OPTION_ARGS" => "",
                    "RETVAL" => "$?",
@@ -121,21 +119,19 @@ EOC
                    "DESC" => "flexible milter management daemon",
                    "NAME" => "milter-manager",
                    "DAEMON" => "/usr/sbin/milter-manager",
-                   "USER" => "milter-manager",
-                   "GROUP" => "mail",
-                   "SOCKET_GROUP" => "mail",
+                   "USER" => "",
+                   "GROUP" => "",
+                   "SOCKET_GROUP" => "",
                    "PIDFILE" => "/var/run/milter-manager/milter-manager.pid",
                    "CONNECTION_SPEC" => "inet:10025@localhost",
                    "SCRIPTNAME" => "/etc/init.d/milter-manager",
                    "DAEMON_ARGS" => ["--daemon",
                                      "--pid-file",
                                      "/var/run/milter-manager/milter-manager.pid",
-                                     "--connection-spec",
-                                     "unix:/var/run/milter-manager/milter-manager.sock",
-                                     "--user-name",
-                                     "milter-manager",
-                                     "--group-name", "mail",
-                                     "--socket-group-name", "mail",
+                                     "--connection-spec", "",
+                                     "--user-name", "",
+                                     "--group-name", "",
+                                     "--socket-group-name", "",
                                     ].join(" ") + " ",
                    "OPTION_ARGS" => "",
                    "RETVAL" => "$?",
