@@ -31,4 +31,23 @@ class TestClientContext < Test::Unit::TestCase
     @context.feed(encoder.encode_negotiate(option))
     assert_equal(option, received_option)
   end
+
+  def test_progress
+    assert_true(@context.progress)
+  end
+
+  def test_add_header
+    @context.option = Milter::Option.new
+    @context.option.add_action(Milter::ACTION_ADD_HEADERS)
+    @context.state = Milter::ClientContext::STATE_END_OF_MESSAGE
+    assert_nothing_raised do
+      @context.add_header("foo", "bar")
+    end
+  end
+
+  def test_set_reply
+    assert_nil(@context.format_reply)
+    @context.set_reply(451, "4.7.0", "DNS timeout")
+    assert_equal("451 4.7.0 DNS timeout", @context.format_reply)
+  end
 end
