@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2008-2009  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -40,12 +40,14 @@ struct _MilterWriterPrivate
 {
     GIOChannel *io_channel;
     guint channel_watch_id;
+    guint tag;
 };
 
 enum
 {
     PROP_0,
-    PROP_IO_CHANNEL
+    PROP_IO_CHANNEL,
+    PROP_TAG
 };
 
 MILTER_IMPLEMENT_ERROR_EMITTABLE(error_emittable_init);
@@ -84,6 +86,13 @@ milter_writer_class_init (MilterWriterClass *klass)
                                 G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
     g_object_class_install_property(gobject_class, PROP_IO_CHANNEL, spec);
 
+    spec = g_param_spec_uint("tag",
+                             "Tag",
+                             "The tag of the reader",
+                             0, G_MAXUINT, 0,
+                             G_PARAM_READABLE);
+    g_object_class_install_property(gobject_class, PROP_TAG, spec);
+
     g_type_class_add_private(gobject_class, sizeof(MilterWriterPrivate));
 }
 
@@ -95,6 +104,7 @@ milter_writer_init (MilterWriter *writer)
     priv = MILTER_WRITER_GET_PRIVATE(writer);
     priv->io_channel = NULL;
     priv->channel_watch_id = 0;
+    priv->tag = 0;
 }
 
 static void
@@ -127,12 +137,15 @@ set_property (GObject      *object,
 
     priv = MILTER_WRITER_GET_PRIVATE(object);
     switch (prop_id) {
-      case PROP_IO_CHANNEL:
+    case PROP_IO_CHANNEL:
         priv->io_channel = g_value_get_pointer(value);
         if (priv->io_channel)
             g_io_channel_ref(priv->io_channel);
         break;
-      default:
+    case PROP_TAG:
+        milter_writer_set_tag(MILTER_WRITER(object), g_value_get_uint(value));
+        break;
+    default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
         break;
     }
@@ -148,10 +161,13 @@ get_property (GObject    *object,
 
     priv = MILTER_WRITER_GET_PRIVATE(object);
     switch (prop_id) {
-      case PROP_IO_CHANNEL:
+    case PROP_IO_CHANNEL:
         g_value_set_pointer(value, priv->io_channel);
         break;
-      default:
+    case PROP_TAG:
+        g_value_set_uint(value, priv->tag);
+        break;
+    default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
         break;
     }
@@ -270,7 +286,7 @@ channel_watch_func (GIOChannel *channel, GIOCondition condition, gpointer data)
                     MILTER_WRITER_ERROR,
                     MILTER_WRITER_ERROR_IO_ERROR,
                     "%s", message);
-        milter_error("[writer][error] %s", message);
+        milter_error("[%u] [writer][error] %s", priv->tag, message);
         milter_error_emittable_emit(MILTER_ERROR_EMITTABLE(writer), error);
         g_error_free(error);
         g_free(message);
@@ -278,7 +294,7 @@ channel_watch_func (GIOChannel *channel, GIOCondition condition, gpointer data)
     }
 
     if (!keep_callback) {
-        milter_debug("[writer] removing writer watcher");
+        milter_debug("[%u] [writer] removing writer watcher", priv->tag);
         priv->channel_watch_id = 0;
         milter_finished_emittable_emit(MILTER_FINISHED_EMITTABLE(writer));
     }
@@ -296,6 +312,7 @@ watch_io_channel (MilterWriter *writer)
     priv->channel_watch_id = g_io_add_watch(priv->io_channel,
                                             G_IO_ERR | G_IO_HUP | G_IO_NVAL,
                                             channel_watch_func, writer);
+    milter_debug("[%u] [writer][watch] %u", priv->tag, priv->channel_watch_id);
 }
 
 void
@@ -325,6 +342,13 @@ milter_writer_shutdown (MilterWriter *writer)
     if (priv->channel_watch_id == 0)
         return;
 
+    g_source_remove(priv->channel_watch_id);
+    priv->channel_watch_id = 0;
+
+    if (!g_io_channel_get_close_on_unref(priv->io_channel))
+        return;
+
+    milter_debug("[%u] [writer][shutdown]", priv->tag);
     g_io_channel_shutdown(priv->io_channel, TRUE, &channel_error);
     if (channel_error) {
         GError *error = NULL;
@@ -335,15 +359,28 @@ milter_writer_shutdown (MilterWriter *writer)
             MILTER_WRITER_ERROR_IO_ERROR,
             channel_error,
             "failed to shutdown");
-        milter_error("[writer][error][shutdown] %s", error->message);
+        milter_error("[%u] [writer][error][shutdown] %s",
+                     priv->tag, error->message);
         milter_error_emittable_emit(MILTER_ERROR_EMITTABLE(writer), error);
         g_error_free(error);
-    } else {
-        g_source_remove(priv->channel_watch_id);
-        priv->channel_watch_id = 0;
     }
 }
 
+guint
+milter_writer_get_tag (MilterWriter *writer)
+{
+    return MILTER_WRITER_GET_PRIVATE(writer)->tag;
+}
+
+void
+milter_writer_set_tag (MilterWriter *writer, guint tag)
+{
+    MilterWriterPrivate *priv;
+
+    priv = MILTER_WRITER_GET_PRIVATE(writer);
+    priv->tag = tag;
+}
+
 /*
 vi:ts=4:nowrap:ai:expandtab:sw=4
 */
