@@ -223,6 +223,18 @@ void          milter_manager_configuration_set_suspend_time_on_unacceptable
                                      (MilterManagerConfiguration *configuration,
                                       guint                       suspend_time);
 
+guint         milter_manager_configuration_get_max_connections
+                                     (MilterManagerConfiguration *configuration);
+void          milter_manager_configuration_set_max_connections
+                                     (MilterManagerConfiguration *configuration,
+                                      guint                       max_connections);
+
+guint         milter_manager_configuration_get_max_file_descriptors
+                                     (MilterManagerConfiguration *configuration);
+void          milter_manager_configuration_set_max_file_descriptors
+                                     (MilterManagerConfiguration *configuration,
+                                      guint                       max_file_descriptors);
+
 const gchar  *milter_manager_configuration_get_custom_configuration_directory
                                      (MilterManagerConfiguration *configuration);
 void          milter_manager_configuration_set_custom_configuration_directory
