@@ -42,6 +42,8 @@ void test_daemon (void);
 void test_pid_file (void);
 void test_maintenance_interval (void);
 void test_suspend_time_on_unacceptable (void);
+void test_max_connections (void);
+void test_max_file_descriptors (void);
 void test_custom_configuration_directory (void);
 void test_controller_connection_spec (void);
 void test_manager_connection_spec (void);
@@ -358,6 +360,30 @@ test_suspend_time_on_unacceptable (void)
         milter_manager_configuration_get_suspend_time_on_unacceptable(config));
 }
 
+void
+test_max_connections (void)
+{
+    cut_assert_equal_uint(
+        MILTER_CLIENT_DEFAULT_MAX_CONNECTIONS,
+        milter_manager_configuration_get_max_connections(config));
+    milter_manager_configuration_set_max_connections(config, 10);
+    cut_assert_equal_uint(
+        10,
+        milter_manager_configuration_get_max_connections(config));
+}
+
+void
+test_max_file_descriptors (void)
+{
+    cut_assert_equal_uint(
+        0,
+        milter_manager_configuration_get_max_file_descriptors(config));
+    milter_manager_configuration_set_max_file_descriptors(config, 1024);
+    cut_assert_equal_uint(
+        1024,
+        milter_manager_configuration_get_max_file_descriptors(config));
+}
+
 void
 test_custom_configuration_directory (void)
 {
@@ -509,6 +535,12 @@ milter_assert_default_configuration_helper (MilterManagerConfiguration *config)
     cut_assert_equal_uint(
         MILTER_CLIENT_DEFAULT_SUSPEND_TIME_ON_UNACCEPTABLE,
         milter_manager_configuration_get_suspend_time_on_unacceptable(config));
+    cut_assert_equal_uint(
+        MILTER_CLIENT_DEFAULT_MAX_CONNECTIONS,
+        milter_manager_configuration_get_max_connections(config));
+    cut_assert_equal_uint(
+        0,
+        milter_manager_configuration_get_max_file_descriptors(config));
 
     gcut_assert_equal_enum(
         MILTER_TYPE_STATUS,
@@ -724,6 +756,8 @@ test_clear (void)
     test_daemon();
     test_maintenance_interval();
     test_suspend_time_on_unacceptable();
+    test_max_connections();
+    test_max_file_descriptors();
 
     milter_manager_configuration_clear(config);
     milter_assert_default_configuration(config);
@@ -831,6 +865,7 @@ test_to_xml_full (void)
         "      <name>milter@10025</name>\n"
         "      <enabled>true</enabled>\n"
         "      <fallback-status>accept</fallback-status>\n"
+        "      <evaluation-mode>false</evaluation-mode>\n"
         "      <connection-spec>inet:10025</connection-spec>\n"
         "      <command>test-milter</command>\n"
         "    </milter>\n"
@@ -869,6 +904,7 @@ test_to_xml_signal (void)
         "      <name>milter@10025</name>\n"
         "      <enabled>true</enabled>\n"
         "      <fallback-status>accept</fallback-status>\n"
+        "      <evaluation-mode>false</evaluation-mode>\n"
         "      <connection-spec>inet:10025</connection-spec>\n"
         "      <command>test-milter</command>\n"
         "      <command-options>--user nobody</command-options>\n"
@@ -887,6 +923,7 @@ test_to_xml_signal (void)
         "      <name>milter@10025</name>\n"
         "      <enabled>true</enabled>\n"
         "      <fallback-status>accept</fallback-status>\n"
+        "      <evaluation-mode>false</evaluation-mode>\n"
         "      <connection-spec>inet:10025</connection-spec>\n"
         "      <command>test-milter</command>\n"
         "      <command-options>--user nobody</command-options>\n"
